==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/igr-mask-input.js <==
import * as React from 'react';
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrMaskInputBase } from "./igr-mask-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
export class IgrMaskInput extends IgrMaskInputBase {
    createImplementation() {
        return new MaskInput();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcMaskInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    get valueMode() {
        return this.i.af;
    }
    set valueMode(v) {
        this.i.af = ensureEnum(MaskInputValueMode_$type, v);
    }
    get value() {
        return this.i.ah;
    }
    set value(v) {
        this.i.ah = v;
    }
    /**
     * The mask pattern to apply on the input.
    */
    get mask() {
        return this.i.ag;
    }
    set mask(v) {
        this.i.ag = v;
    }
    connectedCallback() {
        this.i.ai();
    }
}

==> igniteui-react-18.6.1-beta.0.tgz: package/esm2015/lib/igr-mask-input.js <==
import * as React from 'react';
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrMaskInputBase } from "./igr-mask-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
export class IgrMaskInput extends IgrMaskInputBase {
    createImplementation() {
        return new MaskInput();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcMaskInputComponent);
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            id: this.props.id,
            class: this.props.className,
            style: style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    get valueMode() {
        return this.i.ai;
    }
    set valueMode(v) {
        this.i.ai = ensureEnum(MaskInputValueMode_$type, v);
    }
    get value() {
        return this.i.ak;
    }
    set value(v) {
        this.i.ak = v;
    }
    /**
     * The mask pattern to apply on the input.
    */
    get mask() {
        return this.i.aj;
    }
    set mask(v) {
        this.i.aj = v;
    }
    connectedCallback() {
        this.i.al();
    }
}
